@@ -28,22 +28,14 @@
 #include "yaf_exception.h"
 #include "requests/yaf_request_simple.h"
 
+#if PHP_MAJOR_VERSION > 7
+#include "yaf_request_arginfo.h"
+#else
+#include "yaf_request_legacy_arginfo.h"
+#endif
+
 zend_class_entry *yaf_request_simple_ce;
 
-/** {{{ ARG_INFO
- */
-ZEND_BEGIN_ARG_INFO_EX(yaf_request_simple_construct_arginfo, 0, 0, 0)
-	ZEND_ARG_INFO(0, method)
-	ZEND_ARG_INFO(0, module)
-	ZEND_ARG_INFO(0, controller)
-	ZEND_ARG_INFO(0, action)
-	ZEND_ARG_INFO(0, params)
-ZEND_END_ARG_INFO()
-
-ZEND_BEGIN_ARG_INFO_EX(yaf_request_simple_void_arginfo, 0, 0, 0)
-ZEND_END_ARG_INFO()
-/* }}} */
-
 void yaf_request_simple_init(yaf_request_object *request, zend_string *module, zend_string *controller, zend_string *action, zend_string *method, zval *params) /* {{{ */ {
 	if (!method) {
 		const char *method = yaf_request_get_request_method();
@@ -136,8 +128,8 @@ PHP_METHOD(yaf_request_simple, isXmlHttpRequest) {
 /** {{{ yaf_request_simple_methods
  */
 zend_function_entry yaf_request_simple_methods[] = {
-	PHP_ME(yaf_request_simple, __construct,	yaf_request_simple_construct_arginfo, ZEND_ACC_PUBLIC|ZEND_ACC_CTOR)
-	PHP_ME(yaf_request_simple, isXmlHttpRequest,yaf_request_simple_void_arginfo,ZEND_ACC_PUBLIC)
+	PHP_ME(yaf_request_simple, __construct,	arginfo_class_Yaf_Request_Simple___construct, ZEND_ACC_PUBLIC|ZEND_ACC_CTOR)
+	PHP_ME(yaf_request_simple, isXmlHttpRequest, arginfo_class_Yaf_Request_Simple_isXmlHttpRequest, ZEND_ACC_PUBLIC)
 	{NULL, NULL, NULL}
 };
 /* }}} */
