@@ -49,6 +49,14 @@
 
 ZEND_DECLARE_MODULE_GLOBALS(yaf);
 
+zend_string **yaf_known_strings = NULL;
+const char const *yaf_known_chars[] = {
+#define _YAF_CHARS(id, str) str,
+YAF_KNOWN_NAMES(_YAF_CHARS)
+#undef _YAF_CHARS
+	NULL
+};
+
 /* {{{ yaf_functions[]
 */
 zend_function_entry yaf_functions[] = {
@@ -63,6 +71,15 @@ void yaf_iterator_dtor(zend_object_iterator *iter) /* {{{ */ {
 }
 /* }}} */
 
+#if PHP_VERSION_ID >= 70400
+HashTable *yaf_fake_get_gc(zend_object *zobj, zval **table, int *n) /* {{{ */ {
+	*n = 0;
+	*table = NULL;
+	return NULL;
+}
+/* }}} */
+#endif
+
 static int yaf_iterator_valid(zend_object_iterator *iter) /* {{{ */ {
 	return zend_hash_has_more_elements_ex(Z_ARRVAL(iter->data), &(((yaf_iterator*)iter)->pos));
 }
@@ -501,8 +518,25 @@ PHP_GINIT_FUNCTION(yaf)
 */
 PHP_MINIT_FUNCTION(yaf)
 {
+	uint32_t idx = 0;
+
 	REGISTER_INI_ENTRIES();
 
+    yaf_known_strings = malloc(sizeof(yaf_known_chars));
+	while (yaf_known_chars[idx]) {
+		yaf_known_strings[idx] = zend_string_init(yaf_known_chars[idx], strlen(yaf_known_chars[idx]), 1);
+#if PHP_VERSION_ID < 70300
+		zend_string_hash_val(yaf_known_strings[idx]);
+		GC_REFCOUNT(yaf_known_strings[idx]) = 1;
+		GC_FLAGS(yaf_known_strings[idx]) |= IS_STR_INTERNED | IS_STR_PERSISTENT;
+#else
+		zend_string_hash_func(yaf_known_strings[idx]);
+		GC_SET_REFCOUNT(yaf_known_strings[idx], 1);
+		GC_ADD_FLAGS(yaf_known_strings[idx], IS_STR_INTERNED | IS_STR_PERSISTENT);
+#endif
+		idx++;
+	}
+
 	if (yaf_is_use_namespace()) {
 
 		REGISTER_STRINGL_CONSTANT("YAF\\VERSION", PHP_YAF_VERSION, 	sizeof(PHP_YAF_VERSION) - 1, CONST_PERSISTENT | CONST_CS);
@@ -562,8 +596,15 @@ PHP_MINIT_FUNCTION(yaf)
 */
 PHP_MSHUTDOWN_FUNCTION(yaf)
 {
+	uint32_t idx = 0;
+
 	UNREGISTER_INI_ENTRIES();
 
+	for (idx; idx < sizeof(yaf_known_chars)/sizeof(char*) - 1; idx++) {
+		free(yaf_known_strings[idx]);
+	}
+	free(yaf_known_strings);
+
 	return SUCCESS;
 }
 /* }}} */
